(*  :Title:	Code Generation for Matlab *)

(*  :Authors:	Brian L. Evans *)

(*
    :Summary:   To provide the framework for converting some Mathematica
		expressions into Matlab commands
 *)

(*  :Context:	FilterOptimization`CodeGen`  *)

(*  :PackageVersion:  FOP 1.0	@(#)CodeGen.m	1.4	11/20/97  *)

(*
   :Copyright:

Copyright (c) 1993-1997 The Regents of the University of California.
All rights reserved.

Permission is hereby granted, without written agreement and without
license or royalty fees, to use, copy, modify, and distribute this
software and its documentation for any purpose, provided that the above
copyright notice and the following two paragraphs appear in all copies
of this software.

IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY 
FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES 
ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF 
THE UNIVERSITY OF CALIFORNIA HAS BEEN ADVISED OF THE POSSIBILITY OF 
SUCH DAMAGE.

THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE
PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF
CALIFORNIA HAS NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES,
ENHANCEMENTS, OR MODIFICATIONS.
 *)

(*  :History:	*)

(*  :Keywords:	*)

(*  :Source:	*)

(*  :Warning:	*)

(*  :Mathematica Version:  2.0  *)

(*  :Limitation:  *)

(*  :Discussion: *)

(*  :Functions:	*)


BeginPackage[ "FilterOptimization`CodeGen`" ]


(*  U S A G E     I N F O R M A T I O N  *)

abs::usage =
"abs represents the Matlab function of the same name.";

angle::usage =
"angle represents the Matlab function of the same name.";

cos::usage =
"cos represents the Matlab function of the same name.";

cosh::usage =
"cosh represents the Matlab function of the same name.";

exp::usage =
"exp represents the Matlab function of the same name.";

i::usage =
"i represents the unit pure imaginary number Sqrt[-1] in Matlab.";

inv::usage =
"inv represents the Matlab function of the same name.";

length::usage =
"length represents the Matlab function of the same name.";

log::usage =
"log represents the Matlab function of the same name.";

max::usage =
"max represents the Matlab function of the same name.";

min::usage =
"min represents the Matlab function of the same name.";

pi::usage =
"pi represents the constant Pi in Matlab.";

prod::usage =
"prod represents the Matlab function of the same name.";

sign::usage =
"sign represents the Matlab function of the same name.";

sin::usage =
"sin represents the Matlab function of the same name.";

sinh::usage =
"sinh represents the Matlab function of the same name.";

size::usage =
"size represents the Matlab function of the same name.";

sqrt::usage =
"sqrt represents the Matlab function of the same name.";

sum::usage =
"sum represents the Matlab function of the same name.";

tan::usage =
"tan represents the Matlab function of the same name.";

tanh::usage =
"tanh represents the Matlab function of the same name.";

$IntegrationSamplePoints::usage =
"$IntegrationSamplePoints gives the number of sample points to use
when converting a Mathematica definite integration command into
a numerical integration command.";

CodeGeneratorPreprocessor::usage =
"CodeGeneratorPreprocessor[ expr ] is the first pass at code
generation.
This routine pulls out all of the integration commands in expr,
and replaces each variable of integration with a unique variable.
The returned expressions are context free and can be hashed.
This routine returns a list of two items:
{ list of integrate statements, rest of expression }.
Each element of list-of-integrate-statements contains a two-element
list as well: { variable, integrate-command }.";

integrate::usage =
"integrate is a held (inert) version of Integrate, i.e., it will not
try to compute an answer.";

MatlabCodeGen::usage =
"MatlabCodeGen[ expr, filename ] converts the Mathematica expression
expr to matlab code and writes the matlab code to the file filename
as it is being converted.
For sub-expressions in expr, duplicate code will not be generated.
A third argument extends the elimination of duplicate expressions
beyond the current expression.
The default setting is True.
A setting of First means that this is the first expression of many
expressions from which to remove duplicate sub-expressions.
For subsequent expressions, set this argument to False.
For the last expression, set this argument to Last.";

MmaToMatlab::usage =
"MmaToMatlab[expr] returns a string that is the closest Matlab
equivalent to expr.";

(*  E N D     U S A G E     I N F O R M A T I O N  *)


Begin["`Private`"]


(*  Extend the derivatives of Sum and Product  *)
(*  NOTE: The Module is necessary to workaround bugs in Mma 3.0 *)

Unprotect[ D ];
ClearAttributes[ D, ReadProtected ];

DownValues[D] =
	Prepend[ DownValues[D],
		 Literal[ D[ Sum[f_, {i_, irest___}], x_Symbol, drest___ ] ] :>
		   D [ Sum[ D[f, x], {i, irest} ], drest ] /;
		   FreeQ[ {i, irest}, x ] ];

DownValues[D] =
	Prepend[ DownValues[D],
		 Literal[ D[ Sum[f_, {i_, irest___}], {x_Symbol, n_Integer},
		 	     drest___ ] ] :>
		   D [ Sum[ D[f, {x, n}], {i, irest} ], drest ] /;
		   FreeQ[ {i, irest}, x ] ];

DownValues[D] = 
	Prepend[ DownValues[D],
		 Literal[ D[ Product[fi_, {imax_}], x_Symbol, drest___ ] ] :>
		   D[ fi^imax, x, drest ] /;
		   FreeQ[ imax, x ] ];

DownValues[D] = 
	Prepend[ DownValues[D],
		 Literal[ D[ Product[fi_, {i_, irest___}],
			     x_Symbol, drest___ ] ] :>
		  derOfProduct[ fi, {i, irest}, x, drest ] /;
		  FreeQ[ {i, irest}, x ] ];

SetAttributes[ D, ReadProtected ];
Protect[ D ];

derOfProduct[ fi_, {i_, imax_}, x_, drest___ ] :=
	derOfProduct[ fi, {i, 1, imax, 1}, x, drest ]
derOfProduct[ fi_, {i_, imin_, imax_}, x_, drest___ ] :=
	derOfProduct[ fi, {i, imin, imax, 1}, x, drest ]
derOfProduct[ fi_, {i_, imin_, imax_, inc_}, x_, drest___ ] :=
	Module[	{derx, fl, l, fm, m, sum, product},
		l = Unique["l"];
		m = Unique["m"];
		fl = fi /. i -> l;
		fm = fi /. i -> m;

		(* Sum/Product hold their arguments, but we must  *)
		(* evaluate their arguments so that the iteration *)
		(* variables will be the generated unique tokens; *)
		(* we use sum/product first and then substitute.  *)
		derx = sum[ D[fm, x] *
			      product[fl, {l, imin, m-inc, inc}] *
			      product[fl, {l, m+inc, imax, inc}],
			    {m, imin, imax, inc} ];
		D[ derx, drest ] /. { sum -> Sum, product -> Product } ]

(* Settings *)

$IntegrationSamplePoints = 100;


(*  Local Hashing Functions  *)

(*  state of the hash table  *)
hashTableLength = 0;
hashTable = {};
assocTable = {};

hashCoeff[ n_ ] := {1, 3, 5, 2}[[ Mod[n, 4] + 1 ]]

hashCode[ expr_ ] :=
Block [ {chars, entry, factors, len},
	entry = ToString[ InputForm[ expr ] ];
	chars = ToCharacterCode[entry] - 26;
	len = Length[chars];
	factors = Table[ hashCoeff[i], {i, 1, len} ];
	Mod[factors . chars, hashTableLength] + 1 ]

hashTableInit[len_] :=
Block [	{},
	hashTableLength = len;
	hashTable = Table[ {}, {len} ];
	assocTable = Table[ {}, {len} ];
	Null ];

hashTableSearch[ expr_ ] :=
Block [	{index, pattern, possibleMatches},
	index = hashCode[expr];
	possibleMatches = hashTable[[ index ]];
	pos = Position[ possibleMatches, expr ];
	If [ SameQ[pos, {}],
	     { False, Null },
	     { True, assocTable[[ index, pos[[1,1]] ]] } ] ]

hashTableAdd[ expr_, key_ ] :=
Block [	{entry},
	entry = hashCode[expr];
	AppendTo[ hashTable[[entry]], expr ];
	AppendTo[ assocTable[[entry]], key ];
	Null ]

hashTableDestroy[ ] := Block [ {}, hashTable = assocTable = {}; Null ]


(*  Code Generation  *)

(* stripSymbol-- strips package names and appended $num strings from symbols *)
stripSymbol[symbol_] :=
        Block [ {expandedstring, pos, pos1, pos2, symstr},
		symstr = ToString[symbol];
		strlen = StringLength[symstr];
                expandedstring = Characters[symstr];
                pos = Position[expandedstring, "`"];
                pos1 = If [ SameQ[pos, {}], 1, First[Last[pos]] + 1 ];
                pos = Position[expandedstring, "$"];
                pos2 = If [ SameQ[pos, {}], strlen, First[First[pos]] - 1 ];
		Apply[ StringJoin, Take[ expandedstring, {pos1, pos2} ] ] ]

contextDependentQ[ op_ ]:=
	MemberQ[ { integrate, Integrate, Product, Sum, Table }, op ]

makeContextFree[ head_[expr_, {w_, wrest__}] ] :=
	Block [	{intvar, nexexpr, newiterator},
		intvar = Unique[ stripSymbol[w] ];
		(* use Evaluate in case arguments are held *)
		head[ expr /. w -> intvar, Evaluate[ {intvar, wrest} ] ] ]

makeIterator[ integrate, {w_, w0_, w1_} ] :=
	{ w,
	  iterator[ integrate, { w0, w1, (w1-w0)/$IntegrationSamplePoints } ] }
makeIterator[ head_, {w_, w1_} ] :=
	makeIterator[ head, {w, 1, w1} ]
makeIterator[ head_, {w_, w0_, w1_, winc_:1} ] :=
	{ w, iterator[ head, { w0, w1, winc } ] }

makeInitialization[ integrate, token_ ] := Sequence[]	(* no initialization *)
makeInitialization[ Product, token_ ] := { token, initialization[1] }
makeInitialization[ Sum, token_ ] := { token, initialization[0] }
makeInitialization[ Table, token_ ] := { token, initialization[{}] }

makeTerminator[ integrate, newl_ ] := Sequence[]	(* no terminator *)
makeTerminator[ head_, newl_ ] := { Null, terminator[head] }

CodeGeneratorPreprocessor[ x_ ] :=
	Block [	{integralList, newx},

		(* Simplify expressions and rename Integrate to integrate *)
		newx = x //. { Integrate -> integrate,
			       Product[e_, {n_}] :> e^n,
			       Product[e_, {j_, n_}] :> e^n /;
			 	 FreeQ[e, j],
			       Product[e_, {j_, n1_, n2_}] :> e^(n2 - n1 + 1) /;
			 	 FreeQ[e, j],
			       Sum[e_, {n_}] :> n e,
			       Sum[e_, {j_, n_}] :> n e /;
				 FreeQ[e, j],
			       Sum[e_, {j_, n1_, n2_}] :> e (n2 - n1 + 1) /;
				 FreeQ[e, j] };

		codeGeneratorPreprocessor[newx] ]

codeGeneratorPreprocessor[ x_ ] :=
	Block [	{dependentList, newx},
		dependentList = {};

		newx = x /.
		  ( head_[ f_, l_ ] :>
			Block [	{cfexpr, expr, list, newe, newf, newl, token},
				cfexpr = makeContextFree[ head[f, l] ];
				newf = cfexpr[[1]];
				newl = cfexpr[[2]];
				{list, expr} = codeGeneratorPreprocessor[newf];
				token = Unique[ ToLowerCase[ToString[head]] ];
				newe = Apply[head, {expr, newl}];
				dependentList =
				   Join[ dependentList,
					 { makeInitialization[head, token] },
					 { makeIterator[head, newl] },
					 list,
					 { {token, newe} },
					 { makeTerminator[head, newl] } ];
				token ] /;
			contextDependentQ[head] );

		{ dependentList, newx } ]


(*  Code Generation from a subset of Mathematica commands to Matlab *)

(*  mmaToMatlabRules ---  rules to map functions and constants  *)
mmaToMatlabRules =
	Dispatch[ { Abs -> abs,
		    Arg ->  angle,
		    Cos ->  cos,
		    Cosh ->  cosh,
		    Dimensions -> size,
		    Inverse -> inv,
		    Length -> length,
		    Log ->  log,
		    Max ->  max,
		    Min ->  min,
		    Pi  ->  pi,
		    Sign -> sign,
		    Sin ->  sin,
		    Sinh -> sinh,
		    Tan ->  tan,
		    Tanh -> tanh,
		    Complex[0, y_] :> y i,
		    Complex[x_, y_] :> x + y i,
		    Exp[z_]  :> exp[z],
		    Sqrt[z_] :> sqrt[z],
		    z_^(-1/2) :> sqrt[z]^(-1),
		    ArcTan[z_] :> angle[ 1 + i z ],
		    ArcTan[x_, y_]  :> angle[ x + i y ] } ]

(* MmaToMatlab *)
MmaToMatlab[ mmaCode_ ] :=
	Module[ {body, str},
		body = mmaCode //. mmaToMatlabRules;
		str = StringReplace[ ToString[ InputForm[body] ],
				     { "[" -> "(", "]" -> ")",
				       "InputForm" -> "",
				       "$" -> "_",
				       "^" -> ".^",
				       "*" -> ".*",
				       "/" -> "./" } ];
		str = StringReplace[ str, " . " -> "*" ];
		(* convert lists to Matlab vectors/matrices *)
		StringReplace[ str, { "{" -> "[", "}" -> "]" } ] ]

(* matlabContextCode *)
(* -- writes code that has context-dependent parts, like iterators *)
matlabOp[ Product ] = ".*"
matlabOp[ Sum ] = "+"

mmaOpToMatlab[ var_, integrate, w_, ftoken_ ] :=
	StringJoin[ ToString[var], " = ",
		    "trapz(", ToString[w], ", ", ToString[ftoken], ")" ]
mmaOpToMatlab[ var_, Table, i_, ftoken_ ] :=
	StringJoin[ ToString[var], "(", ToString[i], ") = ", ToString[ftoken] ]
mmaOpToMatlab[ var_, op_, _, ftoken_ ] :=
	StringJoin[ ToString[var], " = ", ToString[var], " ",
		    matlabOp[op], " ", ToString[ftoken] ]

writeIterator[ filename_, var_, w0_, w1_, winc_ ] :=
	WriteString[ filename, var, " = [", MmaToMatlab[w0], ":",
		     MmaToMatlab[winc], ":", MmaToMatlab[w1], "]", ";\n" ]

matlabContextCode[ { var_, initialization[x_] }, filename_, newflag_ ] :=
	WriteString[ filename, var, " = ", MmaToMatlab[x], ";\n" ]

matlabContextCode[ { var_, iterator[integrate, {w0_, w1_, winc_}] },
		   filename_, newflag_ ] :=
	writeIterator[ filename, var, w0, w1, winc ]

matlabContextCode[ { var_, iterator[_, {w0_, w1_, winc_}] },
		   filename_, newflag_ ] :=
	Block [ {},
		WriteString[ filename, "for " ];
		writeIterator[ filename, var, w0, w1, winc ] ]

matlabContextCode[ { _, terminator[integrate] }, _, _ ] := Null

matlabContextCode[ { _, terminator[head_] }, filename_, _ ] :=
	WriteString[ filename, "end", ";\n" ];

matlabContextCode[ { var_, head_[f_, iterator_] }, filename_, newflag_ ] :=
	Module[	{ftoken, str1, str2},

		(* Extract the Mma formula being iterated on and code it *)
		ftoken = parseAndGen[ f, 40, MmaToMatlab,
				      filename, ";\n", newflag ];

		(* Generate the code for the Mathematica operator *)
		WriteString[ filename, 
			     mmaOpToMatlab[var, head, First[iterator], ftoken],
			     ";\n" ] ]

(* MatlabCodeGen *)
MatlabCodeGen[ x_, filename_, flag_:True ] :=
	Module[	{body, ii, inContext, numCodeFragments},

		(* separate integral expressions in x, and make variables of *)
		(* context-dependent operations, such as integration, unique *)
		(* (i.e., context free) so we can hash all of x *)
		{ inContext, body } = CodeGeneratorPreprocessor[ x ];

		numCodeFragments = Length[ inContext ];
		For [ ii = 1, ii <= numCodeFragments, ii++, 
		      matlabContextCode[ inContext[[ii]], filename, flag ] ];

		parseAndGen[ body, 40, MmaToMatlab, filename, ";\n", flag ] ]


(*  parse--- break expr into sub-expressions with fewer than thresh leaves *)
parse[ expr_, thresh_, flag_ ] :=
	Block [	{decomposedList, newexpr, oldexpr},
		If [ SameQ[flag, True] || SameQ[flag, First],
		     hashTableInit[1009] ];
		decomposedList = {};
		newexpr = expr;
		While[ ! SameQ[ newexpr, oldexpr ],
			oldexpr = newexpr;
			newexpr = oldexpr /.
			  ( h_[x___] :>
				Block [	{found, newx},
					{found, newx} = hashTableSearch[h[x]];
					If [ ! found,
					     newx = Unique[ "expr" ];
					     hashTableAdd[ h[x], newx ];
					     AppendTo[ decomposedList,
					     	       {newx, h[x]} ] ];
					newx ] /;
				LeafCount[h[x]] < thresh ) ];
		If [ SameQ[flag, True] || SameQ[flag, Last],
		     hashTableDestroy[] ];
		{ decomposedList, newexpr } ]

parseAndGen[ expr_, thresh_, codefun_, file_, trailer_, restart_:True ] :=
Block [	{bodyvar, code, e, leftover, parsed, x},
	{ parsed, leftover } = parse[expr, thresh, restart];

	(*  Generate code for the decomposed expression *)
	Scan[ Function[ arg,
		x = arg[[1]]; e = arg[[2]];
		WriteString[ file, x, " = ", codefun[e], trailer ] ],
	      parsed ];

	(*  Process the leftover part of the decomposed expression  *)
	code = codefun[leftover];
	If [ SameQ[Head[leftover], Symbol] && SameQ[ToString[leftover], code],
	     bodyvar = leftover,
	     bodyvar = Unique[ "expr" ];
	     WriteString[ file, bodyvar, " = ", code, trailer ] ];

	bodyvar ]


End[]
EndPackage[]

Protect[ $IntegrationSamplePoints, CodeGeneratorPreprocessor,
	 integrate,		   MatlabCodeGen,
	 MmaToMatlab ];

Null
