(*
    Assume that the user has given the following parameters

    n       the number of pole pairs
    rules   list of substitution rules for the pole values
    dp      maximum passband loss
    ds      minimum stopband loss

    SCCS  @(#)Analyze.m	1.1	3/8/94
 *)

$DefaultFont = { "Courier", 16 };	(* for plot labels, etc. *)

If [ ! ValueQ[plotstyle], plotstyle = Automatic ];

partFracCoeffAbs[ r_, i_, n_, k_ ] :=
        Block [ {denomsquared, j, numer},
                numer = Product[ ( r[j]^2 + i[j]^2 ), {j, 1, n} ] / (-2 i[k]);
                denomsquared =
                        Product[ If [ SameQ[k, j],
                                      1,
                                      ((r[k] - r[j])^2 + (i[k] - i[j])^2) *
                                      ((r[k] - r[j])^2 + (i[k] + i[j])^2) ],
                                 {j, 1, n} ];
                numer / Sqrt[ denomsquared ] ]

partFracCoeffPhase[ r_, i_, n_, k_ ] :=
        Block [ {j},
                Sum[ If [ SameQ[k, j],
                          Pi/2,
                          - ArcTan[ (r[k] - r[j]), (i[k] - i[j]) ] -
                            ArcTan[ (r[k] - r[j]), (i[k] + i[j]) ] ],
                     {j, 1, n} ] ]

peakTimeList[ r_, i_, n_ ] :=
        Block [ {Aphase, j},
                Table[ Aphase = partFracCoeffPhase[r, i, n, j];
		       ( Aphase + Pi/2 ) / (- i[j]),
                       {j, 1, n} ] ]

peakTimeWeights[ r_, i_, n_ ] :=
        Block [ {Amag, Aphase, c, d, j},
                Table[ Amag = partFracCoeffAbs[r, i, n, j];
                       Aphase = partFracCoeffPhase[r, i, n, j];
                       d = -2 Amag ( i[j] Sin[Aphase] + r[j] Cos[Aphase] );
		       Exp[ d / ( r[j]^2 + i[j]^2 ) ],
                       {j, 1, n} ] ]

trans = Product[ (r[j]^2 + i[j]^2) / ((s - r[j] - I i[j])(s - r[j] + I i[j])),
		 {j, 1, n} ]
freqresp = trans /. rules /. s -> I w;
magplot1 =
Plot[ 20 Log[10, Abs[freqresp]], {w, 0, 3*ws},
      PlotRange -> All,
      AxesLabel -> { FontForm[w, {"Symbol", 14}], " " },
      PlotStyle -> plotstyle,
      PlotLabel -> "Magnitude Response (dB)" ];
phaseplot1 =
Plot[ Arg[freqresp], {w, 0, wp},
      PlotStyle -> plotstyle,
      AxesLabel -> { FontForm[w, {"Symbol", 14}], " " },
      PlotLabel -> "Phase Response" ];

<<../Filters.m
magresp = magnitude[r, i, n, w] /. rules;
magplot2 =
Plot[ 20 Log[10, magresp], {w, 0, 3*ws},
      AxesLabel -> { FontForm[w, {"Symbol", 14}], " " },
      PlotRange -> All,
      PlotLabel -> "Magnitude Response (dB) from magnitude" ];
phaseresp = phase[r, i, n, w] /. ArcTan[x_, y_] :> ArcTan[y/x] /. rules;
slope = N[ linearPhaseSlope[r, i, n, wp] /. rules ];
Print[ "Slope of the line that best fits the phase response = ",  slope ];
phaseplot2 =
Plot[ {phaseresp, slope w}, {w, 0, wp},
      AxesLabel -> { FontForm[w, {"Symbol", 14}], " " },
      PlotStyle -> { Thickness[0.006], Dashing[{0.05,0.05}] },
      PlotLabel -> "Phase Response from phase" ];

Print[ "quality measure = ", N[ quality[r, i, n] /. rules ] ];
Print[ "quality spread = ",
       N[ Table[ qualityOneSection[r, i, j], {j, 1, n} ] /. rules ] ];

Print[ "magnitude response at wp: ", magresp /. w -> wp, " >= ", 1 - dp ];
Print[ "magnitude response at ws: ", magresp /. w -> ws, " <= ", ds ];

Needs[ "SignalProcessing`Master`" ];
trans2 = Product[ (r[j]^2 + i[j]^2) /
		 Expand[ (s - r[j] - I i[j])(s - r[j] + I i[j]) ],
		 {j, 1, n} ] /. rules;
apart = Apart[ trans2, s ];
Print[ "The partial fractions expansion of the transfer function:" ];
Print[ apart ];
timeresp =
    TheFunction[ InvLaPlace[apart/s, s, t, Apart -> All, Dialogue -> False ] ];
Print[ "Here is the inverse Laplace transform: ", timeresp ];
stepplot =
Plot[ Re[ timeresp ], {t, 0, 1}, PlotRange -> All,
      AxesLabel -> { FontForm[t, {"Roman", 16}], " " },
      PlotRange -> { {0, 1}, {0, 1.25}},
      PlotStyle -> plotstyle,
      PlotLabel -> "Step Response" ]

Print[ "spread of peak step response times: " ];
plist = N[ peakTimeList[r, i, n] /. rules ];
Print[ plist ];
tbar = Apply[ Plus, plist ] / n;
Print[ "average peak step response time: ", tbar ];
wlist = N[ peakTimeWeights[r, i, n] /. rules ];
Print[ "average peak step response time: ",
	( wlist . plist ) / Apply[Plus, wlist] ];

Print[ "Time at which peak occurs: ",
	FindMinimum[ Re[-timeresp], {t, tbar/2, tbar} ] ];
