function [f,g]=filcost1(x)
% FILCOST1(x) returns the cost function for an analog filter
%
%	x contains the real parts of the 1 pole pairs concatenated with
%	the imaginary parts of the 1 pole pairs.
%
%	Code Generated by Mathematica packages written by Brian L. Evans
%	Copyright 1993 by the University of California

%% Extract real and imaginary components of the filters's poles a +/- j b
a = x(1:1);
b = x(2:2);

%% Global parameters
global dp ds maxO wmax Wmp Wms Wmt WO wp Wph WQ ws tpeak1;

%% Parameter settings
%%   weight on mag. response in passband: Wmp
%%   weight on mag. response in transition band: Wmt
%%   weight on mag. response in stopband: Wms
%%   weight on deviation from linear phase: Wph
%%   weight on quality factor cost: WQ
%%   weight on percent overshoot cost: WO
%%   end of passband frequency: wp
%%   start of stopband frequency: ws
%%   max. frequency for filter to exhibit linear phase: wmax
%%   max. percent overshoot of the step response: maxO
%%   allowable mag. error in the passband: dp
%%   allowable mag. error in the stopband: ds

%% Code to compute the constraints

%% Constraints on the quality factors
if wp < 62831.9
   qmax1 = 10;
else
   qmax1 = 25;
end
g(1) = -qmax1 - sqrt(a(1).^2 + b(1).^2)./(2.*a(1));

%% Constraints to check the passband response
g(2) = -1 - eps + (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(1).^2 - b(1).^2)))./100);
g(3) = 1 - dp - eps - (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(1).^2 - b(1).^2)))./100);
g(4) = -1 - eps + (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(1).^2 - b(1).^2)))./25);
g(5) = 1 - dp - eps - (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(1).^2 - b(1).^2)))./25);
g(6) = -1 - eps + (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100);
g(7) = 1 - dp - eps - (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100);
g(8) = -1 - eps + (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25);
g(9) = 1 - dp - eps - (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25);
g(10) = -1 - eps + (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(1).^2 - b(1).^2)))./4);
g(11) = 1 - dp - eps - (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(1).^2 - b(1).^2)))./4);
g(12) = -1 - eps + (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25);
g(13) = 1 - dp - eps - (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25);
g(14) = -1 - eps + (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100);
g(15) = 1 - dp - eps - (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100);
g(16) = -1 - eps + (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25);
g(17) = 1 - dp - eps - (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25);
g(18) = -1 - eps + (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100);
g(19) = 1 - dp - eps - (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100);
g(20) = -1 - eps + (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(1).^2 - b(1).^2)));
g(21) = 1 - dp - eps - (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(1).^2 - b(1).^2)));

%% Constraint to check the stopand response
g(22) = -ds - eps + (a(1).^2 + b(1).^2)./sqrt((a(1).^2 + b(1).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(1).^2 - b(1).^2)));

%% Constraint to check the overshoot of the step response
%%  Overshoot is computed by maximizing the function stepresp
tpeak1 = fmin('stepresp', 0, -(pi./b(1)), [], a, b, -1);
g(23) = stepresp(tpeak1, a, b, 1) - 1 - eps - maxO./100;

%% Code to compute the cost function
w1 = [ws:(99.*ws)./100:100.*ws];
expr23 = (a(1).^2 + b(1).^2).^2;
expr24 = ((a(1).^2 + b(1).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(1).^2 - b(1).^2))).^(-1);
expr25 = expr23.*expr24;
integrate1 = trapz(w1, expr25);
w2 = [0:wp./100:wp];
expr26 = a(1).^2 + b(1).^2;
expr27 = sqrt((a(1).^2 + b(1).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(1).^2 - b(1).^2))).^(-1);
expr28 = (-1 + expr26.*expr27).^2;
integrate2 = trapz(w2, expr28);
w3 = [wp:(-wp + ws)./100:ws];
expr29 = ws./(wp - ws);
expr30 = -(w3./(wp - ws));
expr31 = a(1).^2 + b(1).^2;
expr32 = sqrt((a(1).^2 + b(1).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(1).^2 - b(1).^2))).^(-1);
expr33 = (expr29 + expr30 + expr31.*expr32).^2;
integrate3 = trapz(w3, expr33);
w4 = [0:wmax./100:wmax];
expr34 = angle(1 + (i.*(w4 - b(1)))./a(1));
expr35 = angle(1 + (i.*(w4 + b(1)))./a(1));
expr36 = -3./2;
expr37 = wmax.^(-3);
expr38 = -2.*wmax.*a(1);
expr39 = angle(1 + (i.*(wmax - b(1)))./a(1)) + angle(1 + (i.*(wmax + b(1)))./a(1));
expr40 = -wmax.^2 - a(1).^2 + b(1).^2;
expr41 = -(a(1).*b(1).*log(1 + (wmax - b(1)).^2./a(1).^2));
expr42 = a(1).*b(1).*log(1 + (wmax + b(1)).^2./a(1).^2);
expr43 = (expr34 + expr35 + expr36.*expr37.*(expr38 - expr39.*expr40 + expr41 + expr42).*w4).^2;
integrate4 = trapz(w4, expr43);
expr44 = (integrate2.*Wmp)./wp;
expr45 = (integrate4.*Wph)./wmax;
expr46 = (integrate1.*Wms)./(99.*ws);
expr47 = (integrate3.*Wmt)./(-wp + ws);
expr48 = WQ.*(-0.5 - sqrt(a(1).^2 + b(1).^2)./(2.*a(1)));
expr49 = 100.*WO.*exp(2.*tpeak1.*a(1)).*(cos(tpeak1.*b(1)) - (a(1).*sin(tpeak1.*b(1)))./b(1)).^2;
expr50 = expr44 + expr45 + expr46 + expr47 + expr48 + expr49;
f = expr50;

%% Debugging code
global numtimes weights;
weights = weights + [ (integrate1.*Wms)./(99.*ws) (integrate2.*Wmp)./wp (integrate3.*Wmt)./(-wp + ws) (integrate4.*Wph)./wmax ] / f;
numtimes = numtimes + 1;

end
