function [f,g]=filcost2(x)
% FILCOST2(x) returns the cost function for an analog filter
%
%	x contains the real parts of the 2 pole pairs concatenated with
%	the imaginary parts of the 2 pole pairs.
%
%	Code Generated by Mathematica packages written by Brian L. Evans
%	Copyright 1993 by the University of California

%% Extract real and imaginary components of the filters's poles a +/- j b
a = x(1:2);
b = x(3:4);

%% Global parameters
global dp ds maxO wmax Wmp Wms Wmt WO wp Wph WQ ws tpeak1;

%% Parameter settings
%%   weight on mag. response in passband: Wmp
%%   weight on mag. response in transition band: Wmt
%%   weight on mag. response in stopband: Wms
%%   weight on deviation from linear phase: Wph
%%   weight on quality factor cost: WQ
%%   weight on percent overshoot cost: WO
%%   end of passband frequency: wp
%%   start of stopband frequency: ws
%%   max. frequency for filter to exhibit linear phase: wmax
%%   max. percent overshoot of the step response: maxO
%%   allowable mag. error in the passband: dp
%%   allowable mag. error in the stopband: ds

%% Code to compute the constraints

%% Constraints on the quality factors
if wp < 62831.9
   qmax1 = 10;
else
   qmax1 = 25;
end
g(1) = -qmax1 - sqrt(a(1).^2 + b(1).^2)./(2.*a(1));
g(2) = -qmax1 - sqrt(a(2).^2 + b(2).^2)./(2.*a(2));

%% Constraints to check the passband response
g(3) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(2).^2 - b(2).^2)))./100));
g(4) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(2).^2 - b(2).^2)))./100));
g(5) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(2).^2 - b(2).^2)))./25));
g(6) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(2).^2 - b(2).^2)))./25));
g(7) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100));
g(8) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100));
g(9) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25));
g(10) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25));
g(11) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(1).^2 - b(1).^2)))./4).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(2).^2 - b(2).^2)))./4));
g(12) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(1).^2 - b(1).^2)))./4).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(2).^2 - b(2).^2)))./4));
g(13) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25));
g(14) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25));
g(15) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100));
g(16) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100));
g(17) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25));
g(18) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25));
g(19) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100));
g(20) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100));
g(21) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(2).^2 - b(2).^2))));
g(22) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(2).^2 - b(2).^2))));

%% Constraint to check the stopand response
g(23) = -ds - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(2).^2 - b(2).^2))));

%% Constraint to check the overshoot of the step response
%%  Overshoot is computed by maximizing the function stepresp
tpeak1 = fmin('stepresp', 0, max([-(pi./b(1)), -(pi./b(2))]), [], a, b, -1);
g(24) = stepresp(tpeak1, a, b, 1) - 1 - eps - maxO./100;

%% Code to compute the cost function
w1 = [ws:(99.*ws)./100:100.*ws];
expr23 = (a(1).^2 + b(1).^2).^2;
expr24 = ((a(1).^2 + b(1).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(1).^2 - b(1).^2))).^(-1);
expr25 = (a(2).^2 + b(2).^2).^2;
expr26 = ((a(2).^2 + b(2).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(2).^2 - b(2).^2))).^(-1);
expr27 = expr23.*expr24.*expr25.*expr26;
integrate1 = trapz(w1, expr27);
w2 = [0:wp./100:wp];
expr28 = a(1).^2 + b(1).^2;
expr29 = a(2).^2 + b(2).^2;
expr30 = (a(1).^2 + b(1).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(1).^2 - b(1).^2));
expr31 = (a(2).^2 + b(2).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(2).^2 - b(2).^2));
expr32 = -1./2;
expr33 = (-1 + expr28.*expr29.*(expr30.*expr31).^expr32).^2;
integrate2 = trapz(w2, expr33);
w3 = [wp:(-wp + ws)./100:ws];
expr34 = ws./(wp - ws);
expr35 = -(w3./(wp - ws));
expr36 = a(1).^2 + b(1).^2;
expr37 = a(2).^2 + b(2).^2;
expr38 = (a(1).^2 + b(1).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(1).^2 - b(1).^2));
expr39 = (a(2).^2 + b(2).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(2).^2 - b(2).^2));
expr40 = -1./2;
expr41 = (expr34 + expr35 + expr36.*expr37.*(expr38.*expr39).^expr40).^2;
integrate3 = trapz(w3, expr41);
w4 = [0:wmax./100:wmax];
expr42 = angle(1 + (i.*(w4 - b(1)))./a(1));
expr43 = angle(1 + (i.*(w4 + b(1)))./a(1));
expr44 = angle(1 + (i.*(w4 - b(2)))./a(2));
expr45 = angle(1 + (i.*(w4 + b(2)))./a(2));
expr46 = wmax.^(-3);
expr47 = 1./2;
expr48 = -2.*wmax.*a(1);
expr49 = angle(1 + (i.*(wmax - b(1)))./a(1)) + angle(1 + (i.*(wmax + b(1)))./a(1));
expr50 = -wmax.^2 - a(1).^2 + b(1).^2;
expr51 = -(a(1).*b(1).*log(1 + (wmax - b(1)).^2./a(1).^2));
expr52 = a(1).*b(1).*log(1 + (wmax + b(1)).^2./a(1).^2);
expr53 = -2.*wmax.*a(2);
expr54 = angle(1 + (i.*(wmax - b(2)))./a(2)) + angle(1 + (i.*(wmax + b(2)))./a(2));
expr55 = -wmax.^2 - a(2).^2 + b(2).^2;
expr56 = -(a(2).*b(2).*log(1 + (wmax - b(2)).^2./a(2).^2));
expr57 = a(2).*b(2).*log(1 + (wmax + b(2)).^2./a(2).^2);
expr58 = (expr42 + expr43 + expr44 + expr45 - 3.*expr46.*(expr47.*(expr48 - expr49.*expr50 + expr51 + expr52) + expr47.*(expr53 - expr54.*expr55 + expr56 + expr57)).*w4).^2;
integrate4 = trapz(w4, expr58);
expr59 = (integrate2.*Wmp)./wp;
expr60 = (integrate4.*Wph)./wmax;
expr61 = (integrate1.*Wms)./(99.*ws);
expr62 = (integrate3.*Wmt)./(-wp + ws);
expr63 = 1./2;
expr64 = sqrt((sqrt(a(1).^2 + b(1).^2).*sqrt(a(2).^2 + b(2).^2))./(a(1).*a(2)));
expr65 = b(1).^(-1);
expr66 = a(2).^2 + b(2).^2;
expr67 = ((a(1) - a(2)).^2 + (b(1) - b(2)).^2).*((a(1) - a(2)).^2 + (b(1) + b(2)).^2);
expr68 = -1./2;
expr69 = b(1).*cos(angle(1 + (i.*(b(1) - b(2)))./(a(1) - a(2))) + angle(1 + (i.*(b(1) + b(2)))./(a(1) - a(2))));
expr70 = a(1).*sin(angle(1 + (i.*(b(1) - b(2)))./(a(1) - a(2))) + angle(1 + (i.*(b(1) + b(2)))./(a(1) - a(2))));
expr71 = exp(tpeak1.*a(1));
expr72 = cos(tpeak1.*b(1));
expr73 = a(1);
expr74 = a(1).^2 + b(1).^2;
expr75 = sin(angle(1 + (i.*(b(1) - b(2)))./(a(1) - a(2))) + angle(1 + (i.*(b(1) + b(2)))./(a(1) - a(2))));
expr76 = sin(tpeak1.*b(1));
expr77 = b(2).^(-1);
expr78 = ((-a(1) + a(2)).^2 + (-b(1) + b(2)).^2).*((-a(1) + a(2)).^2 + (b(1) + b(2)).^2);
expr79 = b(2).*cos(angle(1 + (i.*(-b(1) + b(2)))./(-a(1) + a(2))) + angle(1 + (i.*(b(1) + b(2)))./(-a(1) + a(2))));
expr80 = a(2).*sin(angle(1 + (i.*(-b(1) + b(2)))./(-a(1) + a(2))) + angle(1 + (i.*(b(1) + b(2)))./(-a(1) + a(2))));
expr81 = exp(tpeak1.*a(2));
expr82 = cos(tpeak1.*b(2));
expr83 = a(2);
expr84 = sin(angle(1 + (i.*(-b(1) + b(2)))./(-a(1) + a(2))) + angle(1 + (i.*(b(1) + b(2)))./(-a(1) + a(2))));
expr85 = sin(tpeak1.*b(2));
expr86 = expr65.*expr66.*expr67.^expr68.*(expr69 + expr70).*(1 - expr71.*(expr72 - expr65.*(expr73 - (expr74.*expr75)./(expr69 + expr70)).*expr76));
expr87 = expr74.*expr77.*expr78.^expr68.*(expr79 + expr80).*(1 - expr81.*(expr82 - expr77.*(expr83 - (expr66.*expr84)./(expr79 + expr80)).*expr85));
expr88 = (-0.5 + expr63.*expr64).*WQ;
expr89 = expr59 + expr60 + expr61 + expr62 + expr88 + 100.*(-1 + expr86 + expr87).^2.*WO;
f = expr89;

%% Debugging code
global numtimes weights;
weights = weights + [ (integrate1.*Wms)./(99.*ws) (integrate2.*Wmp)./wp (integrate3.*Wmt)./(-wp + ws) (integrate4.*Wph)./wmax ] / f;
numtimes = numtimes + 1;

end
