function [f,g]=filcost3(x)
% FILCOST3(x) returns the cost function for an analog filter
%
%	x contains the real parts of the 3 pole pairs concatenated with
%	the imaginary parts of the 3 pole pairs.
%
%	Code Generated by Mathematica packages written by Brian L. Evans
%	Copyright 1993 by the University of California

%% Extract real and imaginary components of the filters's poles a +/- j b
a = x(1:3);
b = x(4:6);

%% Global parameters
global dp ds maxO wmax Wmp Wms Wmt WO wp Wph WQ ws tpeak1;

%% Parameter settings
%%   weight on mag. response in passband: Wmp
%%   weight on mag. response in transition band: Wmt
%%   weight on mag. response in stopband: Wms
%%   weight on deviation from linear phase: Wph
%%   weight on quality factor cost: WQ
%%   weight on percent overshoot cost: WO
%%   end of passband frequency: wp
%%   start of stopband frequency: ws
%%   max. frequency for filter to exhibit linear phase: wmax
%%   max. percent overshoot of the step response: maxO
%%   allowable mag. error in the passband: dp
%%   allowable mag. error in the stopband: ds

%% Code to compute the constraints

%% Constraints on the quality factors
if wp < 62831.9
   qmax1 = 10;
else
   qmax1 = 25;
end
g(1) = -qmax1 - sqrt(a(1).^2 + b(1).^2)./(2.*a(1));
g(2) = -qmax1 - sqrt(a(2).^2 + b(2).^2)./(2.*a(2));
g(3) = -qmax1 - sqrt(a(3).^2 + b(3).^2)./(2.*a(3));

%% Constraints to check the passband response
g(4) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(3).^2 - b(3).^2)))./100));
g(5) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(3).^2 - b(3).^2)))./100));
g(6) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(3).^2 - b(3).^2)))./25));
g(7) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(3).^2 - b(3).^2)))./25));
g(8) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100));
g(9) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100));
g(10) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25));
g(11) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25));
g(12) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(1).^2 - b(1).^2)))./4).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(2).^2 - b(2).^2)))./4).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(3).^2 - b(3).^2)))./4));
g(13) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(1).^2 - b(1).^2)))./4).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(2).^2 - b(2).^2)))./4).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(3).^2 - b(3).^2)))./4));
g(14) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25));
g(15) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25));
g(16) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100));
g(17) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100));
g(18) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25));
g(19) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25));
g(20) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100));
g(21) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100));
g(22) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(2).^2 - b(2).^2))).*((a(3).^2 + b(3).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(3).^2 - b(3).^2))));
g(23) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(2).^2 - b(2).^2))).*((a(3).^2 + b(3).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(3).^2 - b(3).^2))));

%% Constraint to check the stopand response
g(24) = -ds - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(2).^2 - b(2).^2))).*((a(3).^2 + b(3).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(3).^2 - b(3).^2))));

%% Constraint to check the overshoot of the step response
%%  Overshoot is computed by maximizing the function stepresp
tpeak1 = fmin('stepresp', 0, max([-(pi./b(1)), -(pi./b(2)), -(pi./b(3))]), [], a, b, -1);
g(25) = stepresp(tpeak1, a, b, 1) - 1 - eps - maxO./100;

%% Code to compute the cost function
w1 = [ws:(99.*ws)./100:100.*ws];
expr23 = (a(1).^2 + b(1).^2).^2;
expr24 = ((a(1).^2 + b(1).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(1).^2 - b(1).^2))).^(-1);
expr25 = (a(2).^2 + b(2).^2).^2;
expr26 = ((a(2).^2 + b(2).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(2).^2 - b(2).^2))).^(-1);
expr27 = (a(3).^2 + b(3).^2).^2;
expr28 = ((a(3).^2 + b(3).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(3).^2 - b(3).^2))).^(-1);
expr29 = expr23.*expr24.*expr25.*expr26.*expr27.*expr28;
integrate1 = trapz(w1, expr29);
w2 = [0:wp./100:wp];
expr30 = a(1).^2 + b(1).^2;
expr31 = a(2).^2 + b(2).^2;
expr32 = a(3).^2 + b(3).^2;
expr33 = (a(1).^2 + b(1).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(1).^2 - b(1).^2));
expr34 = (a(2).^2 + b(2).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(2).^2 - b(2).^2));
expr35 = (a(3).^2 + b(3).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(3).^2 - b(3).^2));
expr36 = -1./2;
expr37 = (-1 + expr30.*expr31.*expr32.*(expr33.*expr34.*expr35).^expr36).^2;
integrate2 = trapz(w2, expr37);
w3 = [wp:(-wp + ws)./100:ws];
expr38 = ws./(wp - ws);
expr39 = -(w3./(wp - ws));
expr40 = a(1).^2 + b(1).^2;
expr41 = a(2).^2 + b(2).^2;
expr42 = a(3).^2 + b(3).^2;
expr43 = (a(1).^2 + b(1).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(1).^2 - b(1).^2));
expr44 = (a(2).^2 + b(2).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(2).^2 - b(2).^2));
expr45 = (a(3).^2 + b(3).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(3).^2 - b(3).^2));
expr46 = -1./2;
expr47 = (expr38 + expr39 + expr40.*expr41.*expr42.*(expr43.*expr44.*expr45).^expr46).^2;
integrate3 = trapz(w3, expr47);
w4 = [0:wmax./100:wmax];
expr48 = angle(1 + (i.*(w4 - b(1)))./a(1));
expr49 = angle(1 + (i.*(w4 + b(1)))./a(1));
expr50 = angle(1 + (i.*(w4 - b(2)))./a(2));
expr51 = angle(1 + (i.*(w4 + b(2)))./a(2));
expr52 = angle(1 + (i.*(w4 - b(3)))./a(3));
expr53 = angle(1 + (i.*(w4 + b(3)))./a(3));
expr54 = wmax.^(-3);
expr55 = 1./2;
expr56 = -2.*wmax.*a(1);
expr57 = angle(1 + (i.*(wmax - b(1)))./a(1)) + angle(1 + (i.*(wmax + b(1)))./a(1));
expr58 = -wmax.^2 - a(1).^2 + b(1).^2;
expr59 = -(a(1).*b(1).*log(1 + (wmax - b(1)).^2./a(1).^2));
expr60 = a(1).*b(1).*log(1 + (wmax + b(1)).^2./a(1).^2);
expr61 = -2.*wmax.*a(2);
expr62 = angle(1 + (i.*(wmax - b(2)))./a(2)) + angle(1 + (i.*(wmax + b(2)))./a(2));
expr63 = -wmax.^2 - a(2).^2 + b(2).^2;
expr64 = -(a(2).*b(2).*log(1 + (wmax - b(2)).^2./a(2).^2));
expr65 = a(2).*b(2).*log(1 + (wmax + b(2)).^2./a(2).^2);
expr66 = -2.*wmax.*a(3);
expr67 = angle(1 + (i.*(wmax - b(3)))./a(3)) + angle(1 + (i.*(wmax + b(3)))./a(3));
expr68 = -wmax.^2 - a(3).^2 + b(3).^2;
expr69 = -(a(3).*b(3).*log(1 + (wmax - b(3)).^2./a(3).^2));
expr70 = a(3).*b(3).*log(1 + (wmax + b(3)).^2./a(3).^2);
expr71 = -3.*expr54.*(expr55.*(expr56 - expr57.*expr58 + expr59 + expr60) + expr55.*(expr61 - expr62.*expr63 + expr64 + expr65) + expr55.*(expr66 - expr67.*expr68 + expr69 + expr70)).*w4;
expr72 = (expr48 + expr49 + expr50 + expr51 + expr52 + expr53 + expr71).^2;
integrate4 = trapz(w4, expr72);
expr73 = (integrate2.*Wmp)./wp;
expr74 = (integrate4.*Wph)./wmax;
expr75 = (integrate1.*Wms)./(99.*ws);
expr76 = (integrate3.*Wmt)./(-wp + ws);
expr77 = -1./8;
expr78 = a(1).^(-1);
expr79 = a(2).^(-1);
expr80 = a(3).^(-1);
expr81 = sqrt(a(1).^2 + b(1).^2);
expr82 = sqrt(a(2).^2 + b(2).^2);
expr83 = sqrt(a(3).^2 + b(3).^2);
expr84 = 1./3;
expr85 = b(1).^(-1);
expr86 = a(2).^2 + b(2).^2;
expr87 = a(3).^2 + b(3).^2;
expr88 = (a(1) - a(2)).^2 + (b(1) - b(2)).^2;
expr89 = (a(1) - a(2)).^2 + (b(1) + b(2)).^2;
expr90 = (a(1) - a(3)).^2 + (b(1) - b(3)).^2;
expr91 = (a(1) - a(3)).^2 + (b(1) + b(3)).^2;
expr92 = -1./2;
expr93 = b(1);
expr94 = angle(1 + (i.*(b(1) - b(2)))./(a(1) - a(2)));
expr95 = angle(1 + (i.*(b(1) + b(2)))./(a(1) - a(2)));
expr96 = angle(1 + (i.*(b(1) - b(3)))./(a(1) - a(3)));
expr97 = angle(1 + (i.*(b(1) + b(3)))./(a(1) - a(3)));
expr98 = a(1);
expr99 = exp(tpeak1.*a(1));
expr100 = cos(tpeak1.*b(1));
expr101 = a(1).^2 + b(1).^2;
expr102 = sin(tpeak1.*b(1));
expr103 = b(2).^(-1);
expr104 = (-a(1) + a(2)).^2 + (-b(1) + b(2)).^2;
expr105 = (-a(1) + a(2)).^2 + (b(1) + b(2)).^2;
expr106 = (a(2) - a(3)).^2 + (b(2) - b(3)).^2;
expr107 = (a(2) - a(3)).^2 + (b(2) + b(3)).^2;
expr108 = b(2);
expr109 = angle(1 + (i.*(-b(1) + b(2)))./(-a(1) + a(2)));
expr110 = angle(1 + (i.*(b(1) + b(2)))./(-a(1) + a(2)));
expr111 = angle(1 + (i.*(b(2) - b(3)))./(a(2) - a(3)));
expr112 = angle(1 + (i.*(b(2) + b(3)))./(a(2) - a(3)));
expr113 = a(2);
expr114 = exp(tpeak1.*a(2));
expr115 = cos(tpeak1.*b(2));
expr116 = sin(tpeak1.*b(2));
expr117 = b(3).^(-1);
expr118 = (-a(1) + a(3)).^2 + (-b(1) + b(3)).^2;
expr119 = (-a(1) + a(3)).^2 + (b(1) + b(3)).^2;
expr120 = (-a(2) + a(3)).^2 + (-b(2) + b(3)).^2;
expr121 = (-a(2) + a(3)).^2 + (b(2) + b(3)).^2;
expr122 = b(3);
expr123 = angle(1 + (i.*(-b(1) + b(3)))./(-a(1) + a(3)));
expr124 = angle(1 + (i.*(b(1) + b(3)))./(-a(1) + a(3)));
expr125 = angle(1 + (i.*(-b(2) + b(3)))./(-a(2) + a(3)));
expr126 = angle(1 + (i.*(b(2) + b(3)))./(-a(2) + a(3)));
expr127 = a(3);
expr128 = exp(tpeak1.*a(3));
expr129 = cos(tpeak1.*b(3));
expr130 = sin(tpeak1.*b(3));
expr131 = (-0.5 + (expr77.*expr78.*expr79.*expr80.*expr81.*expr82.*expr83).^expr84).*WQ;
expr132 = (expr104.*expr105.*expr106.*expr107).^expr92;
expr133 = expr108.*cos(expr109 + expr110 + expr111 + expr112) + expr113.*sin(expr109 + expr110 + expr111 + expr112);
expr134 = -(expr114.*(expr115 - expr103.*expr116.*(expr113 - (expr86.*sin(expr109 + expr110 + expr111 + expr112))./(expr108.*cos(expr109 + expr110 + expr111 + expr112) + expr113.*sin(expr109 + expr110 + expr111 + expr112)))));
expr135 = (expr118.*expr119.*expr120.*expr121).^expr92;
expr136 = expr122.*cos(expr123 + expr124 + expr125 + expr126) + expr127.*sin(expr123 + expr124 + expr125 + expr126);
expr137 = -(expr128.*(expr129 - expr117.*expr130.*(expr127 - (expr87.*sin(expr123 + expr124 + expr125 + expr126))./(expr122.*cos(expr123 + expr124 + expr125 + expr126) + expr127.*sin(expr123 + expr124 + expr125 + expr126)))));
expr138 = (expr88.*expr89.*expr90.*expr91).^expr92;
expr139 = expr93.*cos(expr94 + expr95 + expr96 + expr97) + expr98.*sin(expr94 + expr95 + expr96 + expr97);
expr140 = -(expr99.*(expr100 - expr102.*expr85.*(expr98 - (expr101.*sin(expr94 + expr95 + expr96 + expr97))./(expr93.*cos(expr94 + expr95 + expr96 + expr97) + expr98.*sin(expr94 + expr95 + expr96 + expr97)))));
expr141 = 100.*(-1 + expr101.*expr117.*expr135.*expr136.*(1 + expr137).*expr86 + expr101.*expr103.*expr132.*expr133.*(1 + expr134).*expr87 + expr138.*expr139.*(1 + expr140).*expr85.*expr86.*expr87).^2.*WO;
expr142 = expr131 + expr141 + expr73 + expr74 + expr75 + expr76;
f = expr142;

%% Debugging code
global numtimes weights;
weights = weights + [ (integrate1.*Wms)./(99.*ws) (integrate2.*Wmp)./wp (integrate3.*Wmt)./(-wp + ws) (integrate4.*Wph)./wmax ] / f;
numtimes = numtimes + 1;

end
