function [f,g]=filcost4(x)
% FILCOST4(x) returns the cost function for an analog filter
%
%	x contains the real parts of the 4 pole pairs concatenated with
%	the imaginary parts of the 4 pole pairs.
%
%	Code Generated by Mathematica packages written by Brian L. Evans
%	Copyright 1993 by the University of California

%% Extract real and imaginary components of the filters's poles a +/- j b
a = x(1:4);
b = x(5:8);

%% Global parameters
global dp ds maxO wmax Wmp Wms Wmt WO wp Wph WQ ws tpeak1;

%% Parameter settings
%%   weight on mag. response in passband: Wmp
%%   weight on mag. response in transition band: Wmt
%%   weight on mag. response in stopband: Wms
%%   weight on deviation from linear phase: Wph
%%   weight on quality factor cost: WQ
%%   weight on percent overshoot cost: WO
%%   end of passband frequency: wp
%%   start of stopband frequency: ws
%%   max. frequency for filter to exhibit linear phase: wmax
%%   max. percent overshoot of the step response: maxO
%%   allowable mag. error in the passband: dp
%%   allowable mag. error in the stopband: ds

%% Code to compute the constraints

%% Constraints on the quality factors
if wp < 62831.9
   qmax1 = 10;
else
   qmax1 = 25;
end
g(1) = -qmax1 - sqrt(a(1).^2 + b(1).^2)./(2.*a(1));
g(2) = -qmax1 - sqrt(a(2).^2 + b(2).^2)./(2.*a(2));
g(3) = -qmax1 - sqrt(a(3).^2 + b(3).^2)./(2.*a(3));
g(4) = -qmax1 - sqrt(a(4).^2 + b(4).^2)./(2.*a(4));

%% Constraints to check the passband response
g(5) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(3).^2 - b(3).^2)))./100).*((a(4).^2 + b(4).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(4).^2 - b(4).^2)))./100));
g(6) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(3).^2 - b(3).^2)))./100).*((a(4).^2 + b(4).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(4).^2 - b(4).^2)))./100));
g(7) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(3).^2 - b(3).^2)))./25).*((a(4).^2 + b(4).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(4).^2 - b(4).^2)))./25));
g(8) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(3).^2 - b(3).^2)))./25).*((a(4).^2 + b(4).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(4).^2 - b(4).^2)))./25));
g(9) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100).*((a(4).^2 + b(4).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(4).^2 - b(4).^2)))./100));
g(10) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100).*((a(4).^2 + b(4).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(4).^2 - b(4).^2)))./100));
g(11) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25).*((a(4).^2 + b(4).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(4).^2 - b(4).^2)))./25));
g(12) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25).*((a(4).^2 + b(4).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(4).^2 - b(4).^2)))./25));
g(13) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(1).^2 - b(1).^2)))./4).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(2).^2 - b(2).^2)))./4).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(3).^2 - b(3).^2)))./4).*((a(4).^2 + b(4).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(4).^2 - b(4).^2)))./4));
g(14) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(1).^2 - b(1).^2)))./4).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(2).^2 - b(2).^2)))./4).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(3).^2 - b(3).^2)))./4).*((a(4).^2 + b(4).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(4).^2 - b(4).^2)))./4));
g(15) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25).*((a(4).^2 + b(4).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(4).^2 - b(4).^2)))./25));
g(16) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25).*((a(4).^2 + b(4).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(4).^2 - b(4).^2)))./25));
g(17) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100).*((a(4).^2 + b(4).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(4).^2 - b(4).^2)))./100));
g(18) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100).*((a(4).^2 + b(4).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(4).^2 - b(4).^2)))./100));
g(19) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25).*((a(4).^2 + b(4).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(4).^2 - b(4).^2)))./25));
g(20) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25).*((a(4).^2 + b(4).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(4).^2 - b(4).^2)))./25));
g(21) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100).*((a(4).^2 + b(4).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(4).^2 - b(4).^2)))./100));
g(22) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100).*((a(4).^2 + b(4).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(4).^2 - b(4).^2)))./100));
g(23) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(2).^2 - b(2).^2))).*((a(3).^2 + b(3).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(3).^2 - b(3).^2))).*((a(4).^2 + b(4).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(4).^2 - b(4).^2))));
g(24) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(2).^2 - b(2).^2))).*((a(3).^2 + b(3).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(3).^2 - b(3).^2))).*((a(4).^2 + b(4).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(4).^2 - b(4).^2))));

%% Constraint to check the stopand response
g(25) = -ds - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(2).^2 - b(2).^2))).*((a(3).^2 + b(3).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(3).^2 - b(3).^2))).*((a(4).^2 + b(4).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(4).^2 - b(4).^2))));

%% Constraint to check the overshoot of the step response
%%  Overshoot is computed by maximizing the function stepresp
tpeak1 = fmin('stepresp', 0, max([-(pi./b(1)), -(pi./b(2)), -(pi./b(3)), -(pi./b(4))]), [], a, b, -1);
g(26) = stepresp(tpeak1, a, b, 1) - 1 - eps - maxO./100;

%% Code to compute the cost function
w1 = [ws:(99.*ws)./100:100.*ws];
expr23 = (a(1).^2 + b(1).^2).^2;
expr24 = ((a(1).^2 + b(1).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(1).^2 - b(1).^2))).^(-1);
expr25 = (a(2).^2 + b(2).^2).^2;
expr26 = ((a(2).^2 + b(2).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(2).^2 - b(2).^2))).^(-1);
expr27 = (a(3).^2 + b(3).^2).^2;
expr28 = ((a(3).^2 + b(3).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(3).^2 - b(3).^2))).^(-1);
expr29 = (a(4).^2 + b(4).^2).^2;
expr30 = ((a(4).^2 + b(4).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(4).^2 - b(4).^2))).^(-1);
expr31 = expr23.*expr24.*expr25.*expr26.*expr27.*expr28.*expr29.*expr30;
integrate1 = trapz(w1, expr31);
w2 = [0:wp./100:wp];
expr32 = a(1).^2 + b(1).^2;
expr33 = a(2).^2 + b(2).^2;
expr34 = a(3).^2 + b(3).^2;
expr35 = a(4).^2 + b(4).^2;
expr36 = (a(1).^2 + b(1).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(1).^2 - b(1).^2));
expr37 = (a(2).^2 + b(2).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(2).^2 - b(2).^2));
expr38 = (a(3).^2 + b(3).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(3).^2 - b(3).^2));
expr39 = (a(4).^2 + b(4).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(4).^2 - b(4).^2));
expr40 = -1./2;
expr41 = (-1 + expr32.*expr33.*expr34.*expr35.*(expr36.*expr37.*expr38.*expr39).^expr40).^2;
integrate2 = trapz(w2, expr41);
w3 = [wp:(-wp + ws)./100:ws];
expr42 = ws./(wp - ws);
expr43 = -(w3./(wp - ws));
expr44 = a(1).^2 + b(1).^2;
expr45 = a(2).^2 + b(2).^2;
expr46 = a(3).^2 + b(3).^2;
expr47 = a(4).^2 + b(4).^2;
expr48 = (a(1).^2 + b(1).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(1).^2 - b(1).^2));
expr49 = (a(2).^2 + b(2).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(2).^2 - b(2).^2));
expr50 = (a(3).^2 + b(3).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(3).^2 - b(3).^2));
expr51 = (a(4).^2 + b(4).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(4).^2 - b(4).^2));
expr52 = -1./2;
expr53 = (expr42 + expr43 + expr44.*expr45.*expr46.*expr47.*(expr48.*expr49.*expr50.*expr51).^expr52).^2;
integrate3 = trapz(w3, expr53);
w4 = [0:wmax./100:wmax];
expr54 = angle(1 + (i.*(w4 - b(1)))./a(1));
expr55 = angle(1 + (i.*(w4 + b(1)))./a(1));
expr56 = angle(1 + (i.*(w4 - b(2)))./a(2));
expr57 = angle(1 + (i.*(w4 + b(2)))./a(2));
expr58 = angle(1 + (i.*(w4 - b(3)))./a(3));
expr59 = angle(1 + (i.*(w4 + b(3)))./a(3));
expr60 = angle(1 + (i.*(w4 - b(4)))./a(4));
expr61 = angle(1 + (i.*(w4 + b(4)))./a(4));
expr62 = wmax.^(-3);
expr63 = 1./2;
expr64 = -2.*wmax.*a(1);
expr65 = angle(1 + (i.*(wmax - b(1)))./a(1)) + angle(1 + (i.*(wmax + b(1)))./a(1));
expr66 = -wmax.^2 - a(1).^2 + b(1).^2;
expr67 = -(a(1).*b(1).*log(1 + (wmax - b(1)).^2./a(1).^2));
expr68 = a(1).*b(1).*log(1 + (wmax + b(1)).^2./a(1).^2);
expr69 = -2.*wmax.*a(2);
expr70 = angle(1 + (i.*(wmax - b(2)))./a(2)) + angle(1 + (i.*(wmax + b(2)))./a(2));
expr71 = -wmax.^2 - a(2).^2 + b(2).^2;
expr72 = -(a(2).*b(2).*log(1 + (wmax - b(2)).^2./a(2).^2));
expr73 = a(2).*b(2).*log(1 + (wmax + b(2)).^2./a(2).^2);
expr74 = -2.*wmax.*a(3);
expr75 = angle(1 + (i.*(wmax - b(3)))./a(3)) + angle(1 + (i.*(wmax + b(3)))./a(3));
expr76 = -wmax.^2 - a(3).^2 + b(3).^2;
expr77 = -(a(3).*b(3).*log(1 + (wmax - b(3)).^2./a(3).^2));
expr78 = a(3).*b(3).*log(1 + (wmax + b(3)).^2./a(3).^2);
expr79 = -2.*wmax.*a(4);
expr80 = angle(1 + (i.*(wmax - b(4)))./a(4)) + angle(1 + (i.*(wmax + b(4)))./a(4));
expr81 = -wmax.^2 - a(4).^2 + b(4).^2;
expr82 = -(a(4).*b(4).*log(1 + (wmax - b(4)).^2./a(4).^2));
expr83 = a(4).*b(4).*log(1 + (wmax + b(4)).^2./a(4).^2);
expr84 = expr63.*(expr64 - expr65.*expr66 + expr67 + expr68);
expr85 = expr63.*(expr69 - expr70.*expr71 + expr72 + expr73);
expr86 = expr63.*(expr74 - expr75.*expr76 + expr77 + expr78);
expr87 = expr63.*(expr79 - expr80.*expr81 + expr82 + expr83);
expr88 = (expr54 + expr55 + expr56 + expr57 + expr58 + expr59 + expr60 + expr61 - 3.*expr62.*(expr84 + expr85 + expr86 + expr87).*w4).^2;
integrate4 = trapz(w4, expr88);
expr89 = (integrate2.*Wmp)./wp;
expr90 = (integrate4.*Wph)./wmax;
expr91 = (integrate1.*Wms)./(99.*ws);
expr92 = (integrate3.*Wmt)./(-wp + ws);
expr93 = 1./2;
expr94 = a(1).^(-1);
expr95 = a(2).^(-1);
expr96 = a(3).^(-1);
expr97 = a(4).^(-1);
expr98 = sqrt(a(1).^2 + b(1).^2);
expr99 = sqrt(a(2).^2 + b(2).^2);
expr100 = sqrt(a(3).^2 + b(3).^2);
expr101 = sqrt(a(4).^2 + b(4).^2);
expr102 = 1./4;
expr103 = b(1).^(-1);
expr104 = a(2).^2 + b(2).^2;
expr105 = a(3).^2 + b(3).^2;
expr106 = a(4).^2 + b(4).^2;
expr107 = (a(1) - a(2)).^2 + (b(1) - b(2)).^2;
expr108 = (a(1) - a(2)).^2 + (b(1) + b(2)).^2;
expr109 = (a(1) - a(3)).^2 + (b(1) - b(3)).^2;
expr110 = (a(1) - a(3)).^2 + (b(1) + b(3)).^2;
expr111 = (a(1) - a(4)).^2 + (b(1) - b(4)).^2;
expr112 = (a(1) - a(4)).^2 + (b(1) + b(4)).^2;
expr113 = -1./2;
expr114 = b(1);
expr115 = angle(1 + (i.*(b(1) - b(2)))./(a(1) - a(2)));
expr116 = angle(1 + (i.*(b(1) + b(2)))./(a(1) - a(2)));
expr117 = angle(1 + (i.*(b(1) - b(3)))./(a(1) - a(3)));
expr118 = angle(1 + (i.*(b(1) + b(3)))./(a(1) - a(3)));
expr119 = angle(1 + (i.*(b(1) - b(4)))./(a(1) - a(4)));
expr120 = angle(1 + (i.*(b(1) + b(4)))./(a(1) - a(4)));
expr121 = a(1);
expr122 = exp(tpeak1.*a(1));
expr123 = cos(tpeak1.*b(1));
expr124 = a(1).^2 + b(1).^2;
expr125 = sin(tpeak1.*b(1));
expr126 = b(2).^(-1);
expr127 = (-a(1) + a(2)).^2 + (-b(1) + b(2)).^2;
expr128 = (-a(1) + a(2)).^2 + (b(1) + b(2)).^2;
expr129 = (a(2) - a(3)).^2 + (b(2) - b(3)).^2;
expr130 = (a(2) - a(3)).^2 + (b(2) + b(3)).^2;
expr131 = (a(2) - a(4)).^2 + (b(2) - b(4)).^2;
expr132 = (a(2) - a(4)).^2 + (b(2) + b(4)).^2;
expr133 = b(2);
expr134 = angle(1 + (i.*(-b(1) + b(2)))./(-a(1) + a(2)));
expr135 = angle(1 + (i.*(b(1) + b(2)))./(-a(1) + a(2)));
expr136 = angle(1 + (i.*(b(2) - b(3)))./(a(2) - a(3)));
expr137 = angle(1 + (i.*(b(2) + b(3)))./(a(2) - a(3)));
expr138 = angle(1 + (i.*(b(2) - b(4)))./(a(2) - a(4)));
expr139 = angle(1 + (i.*(b(2) + b(4)))./(a(2) - a(4)));
expr140 = a(2);
expr141 = exp(tpeak1.*a(2));
expr142 = cos(tpeak1.*b(2));
expr143 = sin(tpeak1.*b(2));
expr144 = b(3).^(-1);
expr145 = (-a(1) + a(3)).^2 + (-b(1) + b(3)).^2;
expr146 = (-a(1) + a(3)).^2 + (b(1) + b(3)).^2;
expr147 = (-a(2) + a(3)).^2 + (-b(2) + b(3)).^2;
expr148 = (-a(2) + a(3)).^2 + (b(2) + b(3)).^2;
expr149 = (a(3) - a(4)).^2 + (b(3) - b(4)).^2;
expr150 = (a(3) - a(4)).^2 + (b(3) + b(4)).^2;
expr151 = b(3);
expr152 = angle(1 + (i.*(-b(1) + b(3)))./(-a(1) + a(3)));
expr153 = angle(1 + (i.*(b(1) + b(3)))./(-a(1) + a(3)));
expr154 = angle(1 + (i.*(-b(2) + b(3)))./(-a(2) + a(3)));
expr155 = angle(1 + (i.*(b(2) + b(3)))./(-a(2) + a(3)));
expr156 = angle(1 + (i.*(b(3) - b(4)))./(a(3) - a(4)));
expr157 = angle(1 + (i.*(b(3) + b(4)))./(a(3) - a(4)));
expr158 = a(3);
expr159 = exp(tpeak1.*a(3));
expr160 = cos(tpeak1.*b(3));
expr161 = sin(tpeak1.*b(3));
expr162 = b(4).^(-1);
expr163 = (-a(1) + a(4)).^2 + (-b(1) + b(4)).^2;
expr164 = (-a(1) + a(4)).^2 + (b(1) + b(4)).^2;
expr165 = (-a(2) + a(4)).^2 + (-b(2) + b(4)).^2;
expr166 = (-a(2) + a(4)).^2 + (b(2) + b(4)).^2;
expr167 = (-a(3) + a(4)).^2 + (-b(3) + b(4)).^2;
expr168 = (-a(3) + a(4)).^2 + (b(3) + b(4)).^2;
expr169 = b(4);
expr170 = angle(1 + (i.*(-b(1) + b(4)))./(-a(1) + a(4)));
expr171 = angle(1 + (i.*(b(1) + b(4)))./(-a(1) + a(4)));
expr172 = angle(1 + (i.*(-b(2) + b(4)))./(-a(2) + a(4)));
expr173 = angle(1 + (i.*(b(2) + b(4)))./(-a(2) + a(4)));
expr174 = angle(1 + (i.*(-b(3) + b(4)))./(-a(3) + a(4)));
expr175 = angle(1 + (i.*(b(3) + b(4)))./(-a(3) + a(4)));
expr176 = a(4);
expr177 = exp(tpeak1.*a(4));
expr178 = cos(tpeak1.*b(4));
expr179 = sin(tpeak1.*b(4));
expr180 = (-0.5 + expr93.*(expr100.*expr101.*expr94.*expr95.*expr96.*expr97.*expr98.*expr99).^expr102).*WQ;
expr181 = (expr107.*expr108.*expr109.*expr110.*expr111.*expr112).^expr113;
expr182 = expr114.*cos(expr115 + expr116 + expr117 + expr118 + expr119 + expr120) + expr121.*sin(expr115 + expr116 + expr117 + expr118 + expr119 + expr120);
expr183 = expr121 - (expr124.*sin(expr115 + expr116 + expr117 + expr118 + expr119 + expr120))./(expr114.*cos(expr115 + expr116 + expr117 + expr118 + expr119 + expr120) + expr121.*sin(expr115 + expr116 + expr117 + expr118 + expr119 + expr120));
expr184 = (expr127.*expr128.*expr129.*expr130.*expr131.*expr132).^expr113;
expr185 = expr133.*cos(expr134 + expr135 + expr136 + expr137 + expr138 + expr139) + expr140.*sin(expr134 + expr135 + expr136 + expr137 + expr138 + expr139);
expr186 = expr140 - (expr104.*sin(expr134 + expr135 + expr136 + expr137 + expr138 + expr139))./(expr133.*cos(expr134 + expr135 + expr136 + expr137 + expr138 + expr139) + expr140.*sin(expr134 + expr135 + expr136 + expr137 + expr138 + expr139));
expr187 = (expr145.*expr146.*expr147.*expr148.*expr149.*expr150).^expr113;
expr188 = expr151.*cos(expr152 + expr153 + expr154 + expr155 + expr156 + expr157) + expr158.*sin(expr152 + expr153 + expr154 + expr155 + expr156 + expr157);
expr189 = expr158 - (expr105.*sin(expr152 + expr153 + expr154 + expr155 + expr156 + expr157))./(expr151.*cos(expr152 + expr153 + expr154 + expr155 + expr156 + expr157) + expr158.*sin(expr152 + expr153 + expr154 + expr155 + expr156 + expr157));
expr190 = (expr163.*expr164.*expr165.*expr166.*expr167.*expr168).^expr113;
expr191 = expr169.*cos(expr170 + expr171 + expr172 + expr173 + expr174 + expr175) + expr176.*sin(expr170 + expr171 + expr172 + expr173 + expr174 + expr175);
expr192 = expr176 - (expr106.*sin(expr170 + expr171 + expr172 + expr173 + expr174 + expr175))./(expr169.*cos(expr170 + expr171 + expr172 + expr173 + expr174 + expr175) + expr176.*sin(expr170 + expr171 + expr172 + expr173 + expr174 + expr175));
expr193 = expr103.*expr104.*expr105.*expr106.*expr181.*expr182.*(1 - expr122.*(expr123 - expr103.*expr125.*expr183));
expr194 = expr105.*expr106.*expr124.*expr126.*expr184.*expr185.*(1 - expr141.*(expr142 - expr126.*expr143.*expr186));
expr195 = expr104.*expr106.*expr124.*expr144.*expr187.*expr188.*(1 - expr159.*(expr160 - expr144.*expr161.*expr189));
expr196 = expr104.*expr105.*expr124.*expr162.*expr190.*expr191.*(1 - expr177.*(expr178 - expr162.*expr179.*expr192));
expr197 = expr180 + expr89 + expr90 + expr91 + expr92 + 100.*(-1 + expr193 + expr194 + expr195 + expr196).^2.*WO;
f = expr197;

%% Debugging code
global numtimes weights;
weights = weights + [ (integrate1.*Wms)./(99.*ws) (integrate2.*Wmp)./wp (integrate3.*Wmt)./(-wp + ws) (integrate4.*Wph)./wmax ] / f;
numtimes = numtimes + 1;

end
