tic
%% Matlab script to run the optimization
%% Code Generated by Mathematica packages written by Brian L. Evans
%% Copyright 1993 by the University of California

%% This program uses the following global variables:
global dp ds maxO wmax Wmp Wms Wmt WO wp Wph WQ ws tpeak1;

%% The following constants have been given default values:
Wmp = 1;             %% weight on mag. response in passband
Wmt = 1;             %% weight on mag. response in transition band
Wms = 1;             %% weight on mag. response in stopband
Wph = 0;             %% weight on deviation from linear phase
WQ = 1;              %% weight on quality factor cost
WO = 1;              %% weight on percent overshoot cost
wp = 20;             %% end of passband frequency
ws = 30;             %% start of stopband frequency
wmax = wp;           %% max. frequency for filter to exhibit linear phase
maxO = 20;           %% max. percent overshoot of the step response
dp = 0.1;            %% allowable mag. error in the passband
ds = 0.1;            %% allowable mag. error in the stopband

%% The program uses one global variable that is updated at each iteration:
%%	tpeak1 the time at which the peak in the step response occurs

%% Debugging code
global numtimes weights;
weights = [0 0 0 0];
numtimes = 0;

%% Initial Guess x0 is a Butterworth filter

%% We can choose the cutoff frequency to be between these two frequencies:
wc1 = wp/(-1 + (1 - dp)^(-2))^(1/16);
wc2 = ws/(-1 + ds^(-2))^(1/16);
if wc1 > wc2
  error( 'The filter order is too low.' );
end;

%% Choose the middle frequency for wc
wc = (wc1 + wc2)./2;
x0 = wc*[cos((23.*pi)./16), cos((21.*pi)./16), cos((19.*pi)./16), cos((17.*pi)./16), sin((23.*pi)./16), sin((21.*pi)./16), sin((19.*pi)./16), sin((17.*pi)./16)];
tpeak1 = fmin( 'stepresp', 0, max([-(pi./x0(5)), -(pi./x0(6)), -(pi./x0(7)), -(pi./x0(8))]), [], x0(1:4), x0(5:8), -1 );
if ( stepresp(tpeak1, x0(1:4), x0(5:8), 1) - 1 ) > maxO./100
  fprintf(1, '  overshoot for the initial guess is higher than minimum.\n');
end

options = foptions;
options(1) = 0;
options(9) = 1;
options(14) = 10;		%% 5*n
errvec = [-100.*eps, -100.*eps, -100.*eps, -100.*eps, -100.*eps, -100.*eps, -100.*eps, -100.*eps];
disp('The original filter cost:');
filcost4(x0)
x0 = [ -3.8862 -29.4281 -29.9036 -31.3402 -20.0727 -1.3090 -1.3690 -0.5930 ];
root = x0;
lastcost = filcost4(root);
bestcost = lastcost;
bestroot = root;
contflag = 1;
numcalls = 0;
while ( numcalls < 100 & contflag ),
  lastcost = options(8);
  [root, options] = constr('filcost4', root, options, [], errvec, 'costder4');
  if ( options(8) < bestcost )
    bestcost = options(8);
    bestroot = root;
  end;
  bestroot
  numcalls = numcalls + 1;
  contflag = abs( ( lastcost - options(8) ) / lastcost ) > 1e-5;
end
disp('The best root is');
bestroot
disp('Its cost is');
bestcost
disp('The gradient at the best root is')
costder4(bestroot)

%% Normalized weight vector
%% weights / numtimes
toc
